@@ -71,8 +71,8 @@ VALID_COLS = [
     "Comment"]
 
 # Variable attributes
-VALID_MIN_ATTR = "_valid_min"
-VALID_MAX_ATTR = "_valid_max"
+VALID_MIN_ATTR = "valid_min_"
+VALID_MAX_ATTR = "valid_max_"
 FILL_VALUE_ATTR = "_FillValue"
 
 DEFAULT_FILL_VALUE = -999
@@ -522,13 +522,13 @@ def __nc2df(
         data = dict()
         for varname in data_vars :
             var = ncfile.variables[varname]
-            floats = var[start_idx:end_idx:steps]
+            values = var[start_idx:end_idx:steps]
 
-            #if hasattr(var, "least_significant_digit") :
-            #    digits = var.least_significant_digit
-            #    floats = np.around(floats, decimals=digits)
+            # Unmask int vars
+            if np.ma.is_masked(values) and np.issubdtype(values.dtype, np.integer) :
+                values = values.data
 
-            data[varname] = floats
+            data[varname] = values
 
         df = DataFrame(data, index=times)
 
@@ -733,3 +733,22 @@ class DefaultDict(defaultdict) :
 
     def __contains__(self, item):
         return True
+
+def nmin(a, b):
+    """Min which returns the other input if one is None"""
+
+    if a is None :
+        return b
+    elif b is None :
+        return a
+    else :
+        return min(a, b)
+
+def nmax(a, b):
+    """Max which returns the other input if one is None"""
+    if a is None :
+        return b
+    elif b is None :
+        return a
+    else :
+        return max(a, b)
\ No newline at end of file
